# Nim CLI Wrapper for the ESV API
# © 2023 Jonathan Bernard

## Simple command-line wrapper around the ESV API.

import std/[httpclient, json, logging]
import cliutils, docopt

when isMainModule:
  const USAGE = """Usage:
  esv_api <reference> [options]

Options:

  --debug                       Log debug information.

  --echo-args                   Echo back the arguments that were passed on the
                                command line for debugging purposes.

  -t, --esv-api-token <token>   Provide the API token on the command line. By
                                default this will be read either from the
                                .esv_api.cfg.json file or the ESV_API_TOKEN
                                envionment variable.
"""

  let consoleLogger = newConsoleLogger(
    levelThreshold=lvlInfo,
    fmtStr="pit - $levelname: ")
  logging.addHandler(consoleLogger)

  try:
    # Parse arguments
    let args = docopt(USAGE, version = PIT_VERSION)

    if args["--debug"]:
      consoleLogger.levelThreshold = lvlDebug

    if args["--echo-args"]: stderr.writeLine($args)

    let cfgFilePath = getEnv("HOME") / ".esv_api.cfg.json"
    let cfgFileJson =
      if fileExists(cfgFilePath): parseFile(cfgFilePath)
      else: newJObject()

    let cfg = CombinedConfig(docopt: args, json: cfgFileJson)

  except CatchableError:
    fatal getCurrentExceptionMsg()
    debug getCurrentException().getStackTrace()
    quit(QuitFailure)
